Release notes
=============

1.1 (2020-04-10)
----------------

- Doc: initize some basics
- Setup: correctly use the relative path of the README file
- Setup: declare 'docs' extra for the documentation
- Setup: declare 'tests' extra for tests
- Setup / osx: use libc++ to compile the extension (xcode >= 10)
- Tests: restrict the pytest version (< 5)


1.0 (2020-03-15)
----------------

Initial release. Extracted from FoFiX.
